@@ -1115,8 +1115,8 @@ lfMsPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       curr.set <- sort(sites.random[sites.k.fold[[i]]])
       if (binom) {
         y.indx <- !(1:J %in% curr.set)
-        y.fit <- y[rep(y.indx, N), drop = FALSE]
-        y.0 <- y[rep(y.indx, N), drop = FALSE]
+        y.fit <- y[rep(y.indx, each = N), drop = FALSE]
+        y.0 <- y[rep(y.indx, each = N), drop = FALSE]
       } else {
         y.indx <- !((z.long.indx + 1) %in% curr.set)
         y.fit <- c(y.big[, -curr.set, , drop = FALSE])
@@ -1249,6 +1249,10 @@ lfMsPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       colnames(out.fit$beta.samples) <- coef.names
       out.fit$alpha.samples <- mcmc(t(out.fit$alpha.samples))
       colnames(out.fit$alpha.samples) <- coef.names.det
+      loadings.names <- paste(rep(sp.names, times = n.factors), 
+      			rep(1:n.factors, each = N), sep = '-')
+      out.fit$lambda.samples <- mcmc(t(out.fit$lambda.samples))
+      colnames(out.fit$lambda.samples) <- loadings.names
       out.fit$w.samples <- array(out.fit$w.samples, dim = c(q, J, n.post.samples))
       out.fit$w.samples <- aperm(out.fit$w.samples, c(3, 1, 2))
       out.fit$X <- X.fit
