@@ -10,6 +10,14 @@ simBinom <- function(J.x, J.y, weights, beta, psi.RE = list(), sp = FALSE,
           warning("'",i, "' is not an argument")
   }
 
+  # Subroutines -----------------------------------------------------------
+  rmvn <- function(n, mu=0, V = matrix(1)){
+    p <- length(mu)
+    if(any(is.na(match(dim(V),p)))){stop("Dimension problem!")}
+    D <- chol(V)
+    t(matrix(rnorm(n*p), ncol=p)%*%D + rep(mu,rep(n,p)))
+  }
+
   # Check function inputs -------------------------------------------------
   # J.x -------------------------------
   if (missing(J.x)) {
@@ -106,7 +114,6 @@ simBinom <- function(J.x, J.y, weights, beta, psi.RE = list(), sp = FALSE,
     if (x.positive) {
       for (i in 2:n.beta) {
         X[, i] <- runif(J, 0, 1)
-        # X[, i] <- abs(min(X[, i])) + X[, i]
       }
     }
   }
@@ -126,7 +133,7 @@ simBinom <- function(J.x, J.y, weights, beta, psi.RE = list(), sp = FALSE,
     for (i in 1:p.svc) {
       Sigma <- mkSpCov(coords, as.matrix(sigma.sq[i]), as.matrix(0), theta[i, ], cov.model)
       # Random spatial process
-      w.mat[, i] <- mvrnorm(1, rep(0, J), Sigma)
+      w.mat[, i] <- rmvn(1, rep(0, J), Sigma)
     }
     X.w <- X[, svc.cols, drop = FALSE]
     # Convert w to a J*ptilde x 1 vector, sorted so that the p.svc values for 
