@@ -105,7 +105,7 @@ extern "C" {
 		 SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
 		 SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, SEXP batchLength_r, 
 		 SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
-		 SEXP samplesInfo_r, SEXP chainInfo_r, SEXP fixedSigmaSq_r);
+		 SEXP samplesInfo_r, SEXP chainInfo_r, SEXP sigmaSqInfo_r);
  
   SEXP spMsPGOccNNGP(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP coords_r, 
 		     SEXP XRE_r, SEXP XpRE_r, SEXP consts_r, SEXP K_r, 
@@ -128,7 +128,7 @@ extern "C" {
 		     SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
 		     SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, SEXP batchLength_r, 
 		     SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
-		     SEXP samplesInfo_r, SEXP chainInfo_r, SEXP fixedSigmaSq_r);
+		     SEXP samplesInfo_r, SEXP chainInfo_r, SEXP sigmaSqInfo_r);
 
   SEXP spMsPGOccPredict(SEXP J_r, SEXP N_r, SEXP pOcc_r, SEXP X0_r, SEXP q_r, 
 		      SEXP obsD_r, SEXP obsPredD_r, SEXP betaSamples_r, 
@@ -340,17 +340,17 @@ extern "C" {
 		    SEXP betaStarting_r, SEXP alphaStarting_r, SEXP sigmaSqPsiStarting_r,
 		    SEXP sigmaSqPStarting_r, SEXP betaStarStarting_r, SEXP alphaStarStarting_r, 
 	            SEXP zStarting_r, SEXP wStarting_r, SEXP phiStarting_r, 
-	            SEXP sigmaSqStarting_r, SEXP lambdaStarting_r, SEXP nuStarting_r, 
+	            SEXP sigmaSqStarting_r, SEXP nuStarting_r, 
 	            SEXP zLongIndx_r, SEXP betaStarIndx_r, SEXP betaLevelIndx_r, 
 		    SEXP alphaStarIndx_r, SEXP alphaLevelIndx_r, SEXP muBeta_r, SEXP muAlpha_r, 
 	            SEXP SigmaBeta_r, SEXP SigmaAlpha_r, SEXP phiA_r, SEXP phiB_r, 
-	            SEXP sigmaSqA_r, SEXP sigmaSqB_r, SEXP lambdaDiagA_r, SEXP lambdaDiagB_r,
-		    SEXP muLambda_r, SEXP sigmaLambda_r, SEXP nuA_r, SEXP nuB_r, 
+	            SEXP sigmaSqA_r, SEXP sigmaSqB_r, SEXP nuA_r, SEXP nuB_r, 
 		    SEXP sigmaSqPsiA_r, SEXP sigmaSqPsiB_r, 
 		    SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
-	            SEXP tuning_r, SEXP lambdaTuning_r, SEXP covModel_r, SEXP nBatch_r, 
+	            SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, 
 	            SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, 
-	            SEXP nReport_r, SEXP samplesInfo_r, SEXP chainInfo_r);
+	            SEXP nReport_r, SEXP samplesInfo_r, SEXP chainInfo_r, 
+		    SEXP fixedParams_r, SEXP sigmaSqIG_r);
 
   SEXP svcTPGBinomNNGP(SEXP y_r, SEXP X_r, SEXP Xw_r, SEXP coords_r, SEXP XRE_r, 
 		       SEXP consts_r, SEXP weights_r, SEXP nRELong_r, 
